<?php

namespace Drupal\Tests\codepen\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests codepen field widgets and formatters.
 *
 * @group codepen
 */
class CodepenTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['node', 'codepen', 'field_ui'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stable9';

  /**
   * {@inheritdoc}
   */
  public static function getInfo() {
    return [
      'name' => 'Codepen field',
      'description' => 'Tests codepen field widgets and formatters.',
      'group' => 'Codepen',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->assertTrue(TRUE);
    // Create Basic page and Article node types.
    if ($this->profile != 'standard') {
      $this->drupalCreateContentType([
        'type' => 'page',
        'name' => 'Basic page',
      ]);
      $this->drupalCreateContentType([
        'type' => 'article',
        'name' => 'Article',
      ]);
    }

    $this->admin_user = $this->drupalCreateUser([
      'access content',
      'access administration pages',
      'administer site configuration',
      'administer content types',
      'administer node fields',
      'administer nodes',
      'create article content',
      'edit any article content',
      'delete any article content',
    ]);
    $this->drupalLogin($this->rootUser);
  }

  /**
   * Test ID validation and the proper codepen display of a valid ID.
   */
  public function testCodepen() {
    $field_name = mb_strtolower($this->randomMachineName());
    // Create a field.
    $field_storage = \Drupal::entityTypeManager()
      ->getStorage('field_storage_config')
      ->create([
        'field_name' => $field_name,
        'entity_type' => 'node',
        'translatable' => FALSE,
        'type' => 'codepen',
        'cardinality' => '1',
      ]);
    $field_storage->save();
    $field = \Drupal::entityTypeManager()->getStorage('field_config')->create([
      'field_storage' => $field_storage,
      'bundle' => 'article',
      'title' => DRUPAL_DISABLED,
    ]);
    $field->save();

    \Drupal::entityTypeManager()
      ->getStorage('entity_form_display')
      ->load('node.article.default')
      ->setComponent($field_name, [
        'type' => 'codepen',
        'settings' => [],
      ])
      ->save();

    \Drupal::entityTypeManager()
      ->getStorage('entity_view_display')
      ->load('node.article.default')
      ->setComponent($field_name, [
        'type' => 'codepen_embed',
      ])
      ->save();

    // Display creation form.
    $this->drupalGet('node/add/article');
    $this->assertSession()
      ->fieldExists("{$field_name}[0][input]");

    // Verify that a valid URL can be submitted.
    $codepen_id = 'eYyRXWe';
    $user_id = 'emmanuelmaltete';
    $value = 'https://codepen.io/' . $user_id . '/pen/' . $codepen_id;

    $edit = [
      "title[0][value]" => 'Test',
      "{$field_name}[0][input]" => $value,
    ];

    $this->submitForm($edit, t('Save'));
    $this->assertSession()
      ->pageTextContains(t('Article Test has been created.'));
    $this->assertSession()->responseContains($field_name);

    // Verify that the codepen is displayed.
    $this->assertSession()->responseContains('codepen-container');
    $this->assertSession()->responseContains($user_id);
    $this->assertSession()->responseContains($codepen_id);

    // Verify that invalid URLs cannot be submitted.
    $this->drupalGet('node/add/article');
    $value = 'non-url-like-gibberish';
    $edit = [
      "title[0][value]" => 'Test1',
      "{$field_name}[0][input]" => $value,
    ];
    $this->submitForm($edit, t('Save'));
    $this->assertSession()
      ->pageTextContains(t('Please provide a valid Codepen URL.'));
  }

}
